package eaadapter.ea2ecore.postprocessings;
/**
 * <copyright>
 * 
 * Copyright (c) Continental AG and others.
 * All rights reserved. This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 
 * which accompanies this distribution, and is
 * available at http://www.eclipse.org/org/documents/epl-v10.php
 * 
 * Contributors: 
 *     Continental AG - Initial API and implementation
 * 
 * </copyright>
 */

import org.eclipse.core.runtime.Assert;
import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.EClassifier;
import org.eclipse.emf.ecore.EReference;

import eaadapter.datatypes.MetaModelType;
import eaadapter.ea2ecore.PostProcessingTemplate;
import eaadapter.ea2ecore.postprocessings.util.EcoreUtil;


public class AddOppositeReferenceForGEASTADL extends PostProcessingTemplate {

	/**
	 * This method is used to add a reference from EAPackableElement to EAPackage
	 * This reference is necessary for GEASTADL. If we won't add it, the
	 * code can't be generated.
	 */
	
	@Override
	public void execute() throws Exception {
		/**
		 * Do this postprocessing step only if it is a east-adl meta-model
		 */
		if (!isEASTADLMetaModel())
			return;
		
		EClass eaPackagableElement = (EClass) findEClassifierByName("EAPackageableElement");
		if (eaPackagableElement == null)
			throw new Exception("Could not find class 'EAPackageableElement'");
		
		EClass eaPackage =  (EClass) findEClassifierByName("EAPackage");
		if (eaPackage == null)
			throw new Exception("Could not find class 'EAPackage'");
		
		EReference elementReference = (EReference) eaPackage.getEStructuralFeature("element");
		if (elementReference == null)
			throw new Exception("Could not find reference 'element' from EAPackage to EAPackagbleElement");
		
		if (elementReference.getEOpposite() != null) {
			Assert.isTrue(elementReference.getEOpposite().getName().equals("EAPackage_element"),String.format("We have a opposite reference for association 'element' (EAPackage to EAPackageableElement), but the name is not equal to 'EAPackage_element', instead it is '%s'. However we need it for the generation process.", elementReference.getEOpposite().getName()));
		} else {
			EReference opposite = ecoreFactory.createEReference();
			opposite.setName("EAPackage_element");
			opposite.setTransient(true);
			opposite.setLowerBound(0);
			opposite.setUpperBound(1);
			opposite.setEType(eaPackage);
			eaPackagableElement.getEStructuralFeatures().add(opposite);		
			opposite.setEOpposite(elementReference);
			elementReference.setEOpposite(opposite);
		}
	}

	private boolean isEASTADLMetaModel() {
		if (this.getRepository().getTypeOfMetaModel().equals(MetaModelType.EASTADL))
			return true;
		return false;
	}
	
}
