/**
 * <copyright>
 * 
 * Copyright (c) Continental AG and others.
 * All rights reserved. This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 
 * which accompanies this distribution, and is
 * available at http://www.eclipse.org/org/documents/epl-v10.php
 * 
 * Contributors: 
 *     Continental AG - Initial API and implementation
 * 
 * </copyright>
 */

package eaadapter.ea2ecore.postprocessings;

import org.eclipse.emf.common.util.TreeIterator;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EPackage;
import org.eclipse.emf.ecore.util.EcoreUtil;

import eaadapter.common.util.ModelConstants;
import eaadapter.ea2ecore.PostProcessingTemplate;


public class NormalizePackageNsURI extends PostProcessingTemplate {

	//private static String prefix = ModelConstants.DEFAULT_NSURI;
	private String version = null; 
	
	public NormalizePackageNsURI(String version) {
		super();
		this.version = version;
	}
	
	@Override
	public void execute() {	
		TreeIterator<EObject> iter = model.eAllContents();
		while (iter.hasNext()) {
			EObject element = (EObject) iter.next();
			if (element instanceof EPackage) {
				createNsURIForEPackage((EPackage) element);
			}
		}
		createNsURIForEPackage((EPackage) EcoreUtil.getRootContainer(model));
		
	}

	private void createNsURIForEPackage(EPackage element) {
		String packagePath = createPathOfEPackage(element);
		String nsUri;
		if (version != null) {
			nsUri = getPrefix() + "/" + version;
		} else {
			nsUri = getPrefix();
		}
		nsUri = nsUri + packagePath;
		element.setNsURI(nsUri);
	}
	
	public String getPrefix(){
		if(metaModelType.equals(ModelConstants.METAMODEL_TYPE_SAFE)){
			return ModelConstants.DEFAULT_SAFE_NSURI;
		}
		
		return ModelConstants.DEFAULT_NSURI;
	}
}
